==> kadu_0.5.0.orig.tar.gz: kadu/modules/voice/translations/voice_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Voice chat</source>
        <translation>Telephonat</translation>
    </message>
    <message>
        <source>Test GSM Encoding</source>
        <translation>Teste Kodierung GSM</translation>
    </message>
    <message>
        <source>Faster compression algorithm (degrades quality)</source>
        <translation>Schnelleres Kompressionsverfahren (schlechtere Qualität)</translation>
    </message>
    <message>
        <source>Cut-off optimization (faster but degrades quality)</source>
        <translation>Cut-Off-Optimierung (schneller aber schlechtere Qualität)</translation>
    </message>
</context>
<context>
    <name>VoiceChatDialog</name>
    <message>
        <source>Voice chat</source>
        <translation>Telephonat</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
</context>
<context>
    <name>VoiceManager</name>
    <message>
        <source>Voice chat</source>
        <translation>Telephonat</translation>
    </message>
    <message>
        <source>User %1 wants to talk with you. Do you accept it?</source>
        <translation>Benutzer %1 will mit Ihnen reden. Wollen Sie das Gespräch beginnen?</translation>
    </message>
    <message>
        <source>Incoming voice chat</source>
        <translation>Anruf</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
    <message>
        <source>Opening DSP Encoder failed.</source>
        <translation>Öffnen des DSP-Kodierers fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Opening sound device failed.</source>
        <translation>Öffnen des Sound-Gerätes fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Testing GSM Encoding. Please talk now (3 seconds).</source>
        <translation>Teste Kodierung GSM. Sprechen Sie bitte jetzt (3 Sekunden lang).</translation>
    </message>
    <message>
        <source>You should hear your recorded sample now.</source>
        <translation>Sie sollten jetzt die Aufnahme hören.</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/voice/translations/voice_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <source>File transfers and voice chats</source>
        <translation>Übertragen von Dateien und Sprachnachrichten</translation>
    </message>
    <message>
        <source>Voice chats</source>
        <translation>Sprachnachrichten</translation>
    </message>
    <message>
        <source>Faster compression algorithm (degrades quality)</source>
        <translation>Schnellere Kompression (schlechtere Qualität)</translation>
    </message>
    <message>
        <source>Cut-off optimization (faster but degrades quality)</source>
        <translation>Cutt-off (schneller aber schlechtere Qualität)</translation>
    </message>
    <message>
        <source>Test GSM Encoding</source>
        <translation>Teste Kodierung GSM</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Voice chat</source>
        <translation>Sprachnachricht</translation>
    </message>
    <message>
        <source>Sending files and voice chats</source>
        <translation>Sende Dateien und Sprachnachrichten</translation>
    </message>
</context>
<context>
    <name>VoiceChatDialog</name>
    <message>
        <source>Voice chat</source>
        <translation>Telephonat</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
</context>
<context>
    <name>VoiceManager</name>
    <message>
        <source>Voice chat</source>
        <translation>Telephonat</translation>
    </message>
    <message>
        <source>User %1 wants to talk with you. Do you accept it?</source>
        <translation>Benutzer %1 will mit Ihnen reden. Wollen Sie das Gespräch beginnen?</translation>
    </message>
    <message>
        <source>Opening DSP Encoder failed.</source>
        <translation>Öffnen des DSP-Kodierers fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Opening sound device failed.</source>
        <translation>Öffnen des Sound-Gerätes fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Testing GSM Encoding. Please talk now (3 seconds).</source>
        <translation>Teste Kodierung GSM. Sprechen Sie bitte jetzt (3 Sekunden lang).</translation>
    </message>
    <message>
        <source>You should hear your recorded sample now.</source>
        <translation>Sie sollten jetzt die Aufnahme hören.</translation>
    </message>
</context>
</TS>
